==> cryptomodel-athanikos-2.1.6.tar.gz: cryptomodel-athanikos-2.1.6/cryptomodel/cryptostore.py <==
from keyring import get_password
from mongoengine import *

operators = {'>': 'greater', '<': 'less', '=': 'equal'}
change_type = {'1': 'increase', '2': 'decrease', '3': 'increase_and_decrease'}
notification_type = {'telegram': 'telegram'}
operation_type = {'1': 'Added', '2': 'Modified', '3': 'Deleted'}


class user_settings(Document):
    meta = {'strict': False}
    userId = IntField()
    preferred_currency = StringField()


class user_notification(Document):
    meta = {'strict': False}
    userId = IntField()
    user_name = StringField()
    user_email = StringField()
    condition_value = LongField()
    field_name = StringField()
    operator = StringField(choices=operators.keys())
    notify_times = LongField()
    notify_every_in_seconds = LongField()
    symbol = StringField()
    last_date_sent = DateField()
    is_active = BooleanField()
    times_sent = IntField()
    channel_type = StringField()


class user_transaction(Document):
    meta = {'strict': False}
    user_id = IntField()
    volume = LongField()
    symbol = StringField()
    value = LongField()
    price = LongField()
    date = DateField()
    source = StringField()
    currency = StringField()
    source_id = ObjectIdField()
    operation = StringField()


class user_channel(Document):
    meta = {'strict': False}
    user_id = IntField()
    channel_type = StringField()
    chat_id = StringField()
    user_email = StringField()

    def set_token(self):
        self.token = get_password(self.notification_type, 'token')

==> cryptomodel-athanikos-2.2.4.tar.gz: cryptomodel-athanikos-2.2.4/cryptomodel/cryptostore.py <==
from keyring import get_password
from mongoengine import *
from enum import Enum


class OPERATIONS(Enum):
    ADDED  = 1
    MODIFIED = 2
    REMOVED = 3

    @classmethod
    def choices(cls):
        return tuple((i.name, i.value) for i in cls)


class user_settings(Document):
    meta = {'strict': False}
    userId = IntField()
    preferred_currency = StringField()


class user_notification(Document):
    meta = {'strict': False}
    user_id = IntField()
    user_name = StringField()
    user_email = StringField()
    expression_to_evaluate = StringField()
    check_every_seconds = LongField()
    check_times = LongField()
    is_active = BooleanField()
    channel_type = StringField()
    fields_to_send = StringField()  ### collection:field latest date ?
    ### collection:field by latest user_id ?
    source_id = ObjectIdField()
    operation = StringField(choices=OPERATIONS)


class user_transaction(Document):
    meta = {'strict': False}
    user_id = IntField()
    volume = LongField()
    symbol = StringField()
    value = LongField()
    price = LongField()
    date = DateField()
    source = StringField()
    currency = StringField()
    source_id = ObjectIdField()
    operation = StringField(choices=OPERATIONS.choices())


class user_channel(Document):
    meta = {'strict': False}
    user_id = IntField()
    channel_type = StringField()
    chat_id = StringField()
    user_email = StringField()

    def set_token(self):
        self.token = get_password(self.notification_type, 'token')
